==> krita_4.4.2+dfsg.orig.tar.xz: krita-4.4.2/plugins/generators/seexpr/generator.h <==
/*
 * This file is part of Krita
 *
 * Copyright (c) 2020 L. E. Segovia <amy@amyspark.me>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef SEEXPR_GENERATOR_H
#define SEEXPR_GENERATOR_H

#include <QObject>
#include <QVariant>

#include "generator/kis_generator.h"

#define BASE_SCRIPT                                                                                                                                                                                                                            \
    "$val=voronoi(5*[$u,$v,.5],4,.6,.2); \n \
$color=ccurve($val,\n\
    0.000, [0.141, 0.059, 0.051], 4,\n\
    0.185, [0.302, 0.176, 0.122], 4,\n\
    0.301, [0.651, 0.447, 0.165], 4,\n\
    0.462, [0.976, 0.976, 0.976], 4);\n\
$color\n\
"

class KisConfigWidget;

class KritaSeExprGenerator : public QObject
{
    Q_OBJECT
public:
    KritaSeExprGenerator(QObject *parent, const QVariantList &);
    ~KritaSeExprGenerator() override;
};

class KisSeExprGenerator : public KisGenerator
{
public:
    KisSeExprGenerator();

    using KisGenerator::generate;

    void generate(KisProcessingInformation dst,
                  const QSize& size,
                  const KisFilterConfigurationSP config,
                  KoUpdater* progressUpdater
                 ) const override;

    static inline KoID id()
    {
        return KoID("seexpr", i18n("SeExpr"));
    }
    KisFilterConfigurationSP defaultConfiguration() const override;
    KisConfigWidget *createConfigurationWidget(QWidget *parent, const KisPaintDeviceSP dev, bool useForMasks) const override;
};

#endif

==> krita_5.2.9+dfsg.orig.tar.xz: krita-5.2.9/plugins/generators/seexpr/generator.h <==
/*
 * This file is part of Krita
 *
 * SPDX-FileCopyrightText: 2020 L. E. Segovia <amy@amyspark.me>
 *
 *  SPDX-License-Identifier: GPL-2.0-or-later
 */

#ifndef SEEXPR_GENERATOR_H
#define SEEXPR_GENERATOR_H

#include <QObject>
#include <QVariant>

#include "generator/kis_generator.h"

#define BASE_SCRIPT                                                                                                                                                                                                                            \
    "$val=voronoi(5*[$u,$v,.5],4,.6,.2); \n \
$color=ccurve($val,\n\
    0.000, [0.141, 0.059, 0.051], 4,\n\
    0.185, [0.302, 0.176, 0.122], 4,\n\
    0.301, [0.651, 0.447, 0.165], 4,\n\
    0.462, [0.976, 0.976, 0.976], 4);\n\
$color\n\
"

class KisConfigWidget;

class KritaSeExprGenerator : public QObject
{
    Q_OBJECT
public:
    KritaSeExprGenerator(QObject *parent, const QVariantList &);
    ~KritaSeExprGenerator() override;
};

class KisSeExprGenerator : public KisGenerator
{
public:
    KisSeExprGenerator();

    using KisGenerator::generate;

    void generate(KisProcessingInformation dst,
                  const QSize& size,
                  const KisFilterConfigurationSP config,
                  KoUpdater* progressUpdater
                 ) const override;

    static inline KoID id()
    {
        return KoID("seexpr", i18n("SeExpr"));
    }
    KisFilterConfigurationSP factoryConfiguration(KisResourcesInterfaceSP resourcesInterface) const override;
    KisFilterConfigurationSP defaultConfiguration(KisResourcesInterfaceSP resourcesInterface) const override;
    KisConfigWidget *createConfigurationWidget(QWidget *parent, const KisPaintDeviceSP dev, bool useForMasks) const override;
};

#endif
